@@ -29,26 +29,20 @@ where
     fn visit_mut_call_expr(&mut self, e: &mut CallExpr) {
         e.visit_mut_children_with(self);
 
-        match &e.callee {
-            Callee::Import(_) => {
-                if let Some(ExprOrSpread { spread: None, expr }) = &mut e.args.get_mut(0) {
-                    match &mut **expr {
-                        Expr::Lit(Lit::Str(s)) => {
-                            let src = self
-                                .resolver
-                                .resolve_import(&self.base, &s.value)
-                                .with_context(|| format!("failed to resolve import `{}`", s.value))
-                                .unwrap();
+        if let Callee::Import(_) = &e.callee {
+            if let Some(ExprOrSpread { spread: None, expr }) = &mut e.args.get_mut(0) {
+                if let Expr::Lit(Lit::Str(s)) = &mut **expr {
+                    let src = self
+                        .resolver
+                        .resolve_import(&self.base, &s.value)
+                        .with_context(|| format!("failed to resolve import `{}`", s.value))
+                        .unwrap();
 
-                            // This string literal is synthesized
-                            s.kind = Default::default();
-                            s.value = src;
-                        }
-                        _ => {}
-                    }
+                    // This string literal is synthesized
+                    s.kind = Default::default();
+                    s.value = src;
                 }
             }
-            _ => {}
         }
     }
 
